<?php
/*
 * post an admin message if no AtD key is set.
 */
if ( !get_option('AtD_api_key') && !$atd_api_key && !isset($_POST['submit']) ) {

	function AtD_warning() {
		echo "<div id='atd-warning' class='updated fade'><p><strong>" . __('After the Deadline is almost ready.', 'after-the-deadline') . '</strong> ' . sprintf(  __( 'You must <a href="%1$s">enter your API key</a> for it to work.', 'after-the-deadline' ), 'plugins.php?page=atd-key-config'  )  . '</p></div>';
	}
	add_action( 'admin_notices', 'AtD_warning' );
}

/* 
 * post an admin message if fsockopen is disabled
 */
if ( !function_exists('fsockopen') ) {

	function AtD_warning_fsockopen() {
		echo "<div id='atd-warning-fsockopen' class='updated fade'><p><strong>" . __("After the Deadine can't connect to the proofreading service.</strong> Contact your system administrator and ask them to allow the use of <em>fsockopen</em> from PHP.", 'after-the-deadline') . "</p></div>";
	}
	add_action( 'admin_notices', 'AtD_warning_fsockopen' );
}

/*
 * connect to the AtD service and verify the key the user entered
 */
function AtD_verify_key( $key ) {
	$session = AtD_http_get( 'service.afterthedeadline.com', '/verify?blog=' . urlencode( get_option( 'home' ) ) . '&key=' . urlencode( $key ));
	return $session[1];
}

/*
 * display the form for the user to enter the key, also saving of the key option is handled here as well.
 */
function AtD_display_key_form() {

	if ( isset($_POST['submit']) ) {
		if ( function_exists( 'current_user_can' ) && ! current_user_can( 'manage_options' ) ) {
			die(  __('Cheatin&#8217; uh?', 'after-the-deadline')  );
		}

		$key = preg_replace( '/[^a-h0-9]/i', '', $_POST['key'] );
	} else {
		$key = get_option( 'AtD_api_key' );
	}

	if ( empty($key) ) {
		$key_status = 'empty';
		$ms[] = isset( $_POST['submit'] ) ? 'new_key_empty' : 'key_empty';
		delete_option( 'AtD_api_key' );
	} else if ( strlen($key) < 32 ) {
		$key_status = 'key_invalid';
		$ms[] = 'new_key_is_wp_key';
		delete_option( 'AtD_api_key' );
	} else {
		$key_status = trim(  AtD_verify_key( $key )  );

		if ( strcmp( $key_status, 'valid' ) == 0 || strcmp( $key_status, 'Got it!' ) == 0) {

			update_option( 'AtD_api_key', $key );
			$ms[] = isset( $_POST['submit'] ) ? 'new_key_valid' : 'key_valid';

		} else if ( strcmp( $key_status, 'invalid' ) == 0 ) {
			delete_option( 'AtD_api_key' );
			$ms[] = isset( $_POST['submit'] ) ? 'new_key_invalid' : 'key_invalid';
		} else {
			$ms[] = isset( $_POST['submit'] ) ? 'new_key_failed' : 'key_failed';
		}
	}

	/* potential messages */

	$messages = array(
		'new_key_is_wp_key' => array('color' => 'd22', 'text' => sprintf(__('A WordPress.com API key doesn\'t work here. (<a href="%s" target="_new" style="color:#fff">Get your After the Deadline API key.</a>)', 'after-the-deadline'), 'http://www.afterthedeadline.com/profile.slp')),
		'new_key_empty' => array('color' => 'aa0', 'text' => __('Your key is cleared.', 'after-the-deadline')),
		'new_key_valid' => array('color' => '2d2', 'text' => __('Your key is now verified. Enjoy!', 'after-the-deadline')),
		'new_key_invalid' => array('color' => 'd22', 'text' => __('The key you entered is invalid. Please check it.', 'after-the-deadline')),
		'new_key_failed' => array('color' => 'd22', 'text' => __('Unable to connect to afterthedeadline.com to verify your key.  Please check your server configuration.', 'after-the-deadline')),
		'key_empty' => array('color' => 'aa0', 'text' => sprintf(__('Please enter an API key. (<a href="%s" target="_new" style="color:#fff">Get your key.</a>)'), 'http://www.afterthedeadline.com/profile.slp', 'after-the-deadline')),
		'key_valid' => array('color' => '2d2', 'text' => __('Your key is valid.', 'after-the-deadline')),
		'key_failed' => array('color' => 'aa0', 'text' => __('Your key was valid but I was unable to connect to afterthedeadline.com and verify it.', 'after-the-deadline'))
	);
   ?>

<!-- show off the options saved -->

<?php if ( !empty($_POST ) ) : ?>
<div id="message" class="updated fade"><p><strong><?php _e('Options saved.', 'after-the-deadline') ?></strong></p></div>
<?php endif; ?>

<di class="wrap">
<h2><?php _e('After the Deadline: Proofreading Software', 'after-the-deadline'); ?></h2>
<div class="narrow">
<form action="" method="post" id="atd-conf" style="width: 400px; margin: auto">
      <p>
         <?php printf(__('Write better and spend less time editing with After the Deadline. To use this plugin you\'ll need an After the Deadline API key.  You can get this from the <a href="%s">After the Deadline</a> website.', 'after-the-deadline'), 'http://www.afterthedeadline.com/profile.slp'); ?>
      </p>

      <h3><label for="key"><?php _e('API Key', 'after-the-deadline'); ?></label></h3>

      <?php
	if ( count($ms) > 0 ) {
		foreach ( $ms as $m ) {
      ?>
        <p style="padding: .5em; background-color: #<?php echo $messages[$m]['color']; ?>; color: #fff; font-weight: bold;"><?php echo $messages[$m]['text']; ?></p>
      <?php
		}
	}
      ?>

     <p>        <input id="key" name="key" type="text" size="32" maxlength="32" value="<?php echo get_option('AtD_api_key'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" />
      </p>

      <p class="submit"><input type="submit" name="submit" value="<?php _e('Update key &raquo;', 'after-the-deadline'); ?>" /></p>

<h3><?php _e('Using', 'after-the-deadline'); ?></h3>

<p><?php printf(__('Click <img src="%s" border="0" alt="the AtD button" /> in the editor to check spelling, style, and grammar.', 'after-the-deadline'), WP_PLUGIN_URL . '/after-the-deadline/button.gif'); ?></p>

<h3><?php _e('Options', 'after-the-deadline'); ?></h3>

<p><?php printf(__('Visit your <a href="%s">profile page</a> to configure After the Deadline proofreading software options.', 'after-the-deadline'), 'profile.php'); ?></p>

<h3><?php _e('Feedback', 'after-the-deadline'); ?></h3>

<p><?php printf(__('Visit <a href="%s">After the Deadline</a> to give feedback, report bugs, and offer suggestions.', 'after-the-deadline'), 'http://www.afterthedeadline.com/support'); ?></p>

</form>
</div>
</div>


<?php 
}
